@@ -6,6 +6,7 @@ from rest_framework import generics
 from rest_framework.permissions import IsAuthenticated, IsAdminUser, AllowAny
 
 from utils.custom_tool import request_params_wrapper
+from xj_finance.services.finance_service import FinanceService
 from ..services.finance_transacts_service import FinanceTransactsService
 from xj_user.services.user_service import UserService
 from ..utils.model_handle import parse_data, util_response
@@ -57,7 +58,8 @@ class FinanceTransact(generics.UpdateAPIView):  # 或继承(APIView)
         if not data:
             return util_response(err=4002, msg=err_txt)
         params = parse_data(request)
-        params['account_id'] = data['user_id']
+        if not params.get("account_id",None):
+            params['account_id'] = data['user_id']
         if not params:
             return util_response(err=6046, msg='至少需要一个请求参数')
         data, err_txt = FinanceTransactService.post(params)
@@ -100,9 +102,9 @@ class FinanceTransact(generics.UpdateAPIView):  # 或继承(APIView)
 
     def finance_flow_writing(self):
         params = parse_data(self)
-        # data, err_txt = FinanceTransactService.finance_flow_writing(params=params,
-        #                                                             finance_type='PAY')
-        data, err_txt = FinanceTransactsService.finance_create_or_write_off(params)
+        data, err_txt = FinanceTransactService.finance_flow_writing(params=params,
+                                                                    finance_type='TRANSACT')
+        # data, err_txt = FinanceTransactsService.finance_create_or_write_off(params)
         if err_txt is None:
             return util_response(data=data)
         return util_response(err=47767, msg=err_txt)
@@ -118,3 +120,12 @@ class FinanceTransact(generics.UpdateAPIView):  # 或继承(APIView)
         if err_txt is None:
             return util_response(data=data)
         return util_response(err=47767, msg=err_txt)
+
+    @request_params_wrapper
+    def balance_validation(self, *args, user_info=None, request_params=None, **kwargs):
+        if request_params is None:
+            request_params = {}
+        data, err_txt = FinanceService.balance_validation(request_params)
+        if err_txt is None:
+            return util_response(data=data)
+        return util_response(err=47767, msg=err_txt)
\ No newline at end of file
