@@ -63,48 +63,11 @@ class FinanceTransacts(generics.UpdateAPIView):  # 或继承(APIView)
             'data': data
         })
 
-    def get_finance_thread(self, *args, **kwargs):
-
-        # ========== 一、验证权限 ==========
-
-        token = self.META.get('HTTP_AUTHORIZATION', '')
-        if not token:
-            return util_response(err=4001, msg='缺少Token')
-
-        # print("get token:", token)
-        data, err_txt = UserService.check_token(token)
-        # print("get data, err_txt:", data, err_txt)
-        if not data:
-            return util_response(err=4002, msg=err_txt)
-
-        # ========== 二、必填性检查 ==========
-
-        params = parse_data(self)
-        data, err_txt = FinanceTransactsService.get_finance_thread(params, data['user_id'])
-        if not data:
-            return util_response(err=4002, msg=err_txt)
-
-        return JsonResponse({
-            'err': 0,
-            'msg': 'OK',
-            'data': data
-        })
-
-        # return HttpResponse(output)
-
-    # 分销
-    def distribution(self):
-        params = parse_data(self)
-        data, err_txt = FinanceTransactsService.distribution(params)
-        if err_txt is None:
-            return util_response(data=data)
-        return util_response(err=47767, msg=err_txt)
-
     # 核销
     def write_off(self):
         params = parse_data(self)
-        # print(params)
-        data, err_txt = FinanceTransactsService.write_off(params)
+        print(params)
+        data, err_txt = FinanceTransactsService.examine_approve(params)
         if err_txt is None:
             return util_response(data=data)
         return util_response(err=47767, msg=err_txt)
@@ -157,7 +120,7 @@ class FinanceTransacts(generics.UpdateAPIView):  # 或继承(APIView)
     # 应收应付生成
     def create_or_write_off(self):
         params = parse_data(self)
-        data, err_txt = FinanceTransactsService.finance_create_or_write_off(params)
-        if err_txt is None:
+        data, err = FinanceTransactsService.finance_create_or_write_off(params)
+        if err is None:
             return util_response(data=data)
-        return util_response(err=47767, msg=err_txt)
+        return util_response(err=47767, msg=err)
