@@ -1,6 +1,7 @@
 from django.db import models
 from django.utils import timezone
 from xj_user.models import Platform, BaseInfo
+from xj_enroll.models import Enroll, EnrollRecord
 from xj_thread.models import Thread
 import time
 
@@ -81,12 +82,6 @@ def make_crc16(self):
 
 
 class Transact(models.Model):
-    account = models.ForeignKey(verbose_name='账户', to=BaseInfo, db_column='account_id', related_name='account_set',
-                                on_delete=models.DO_NOTHING, db_constraint=False)
-    their_account = models.ForeignKey(verbose_name='对方账户', to=BaseInfo, db_column='their_account_id',
-                                      related_name='their_account_set',
-                                      on_delete=models.DO_NOTHING, db_constraint=False)
-
     # 如何获取用户???
     # year_timestamp函数+hash算法
     hex_code = make_crc16('admin')
@@ -94,41 +89,62 @@ class Transact(models.Model):
     zero_code = '0' + str(decimal_code)
     create_transact_id = year_timestamp() + zero_code
 
-    # transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default=create_transact_id) # 应为transact号
+    platform = models.ForeignKey(verbose_name='平台', to=Platform, db_column='platform_id', on_delete=models.DO_NOTHING,
+                                 db_constraint=False,
+                                 default='')
+    thread = models.ForeignKey(verbose_name='信息', to=Thread, db_column='thread_id', on_delete=models.DO_NOTHING,
+                               db_constraint=False,
+                               default='')
     transact_no = models.CharField(verbose_name='交易号', unique=True, max_length=255, blank=True, db_index=True)
-    enroll_id = models.BigIntegerField(verbose_name='报名id', db_index=True, null=True, blank=True, )  # 应为transact号
-    # transact_id = models.BigIntegerField(verbose_name='交易号', unique=True, db_index=True, default='') # 应为transact号
-    transact_time = models.DateTimeField(verbose_name='交易时间', auto_now_add=True)
-    # platform = models.ForeignKey(verbose_name='平台', to=Platform, db_column='platform_id', on_delete=models.DO_NOTHING, default='')
-    platform_id = models.IntegerField(verbose_name='平台', default='')
-    # platform_order_id = models.BigIntegerField(verbose_name='平台订单号', db_index=True, default=year_timestamp() + zero_code)
+    enroll = models.ForeignKey(verbose_name='报名', to=Enroll, db_column='enroll_id', on_delete=models.DO_NOTHING,
+                               db_constraint=False,
+                               default='')
+    enroll_record = models.ForeignKey(verbose_name='报名详情', to=EnrollRecord, db_column='enroll_record_id',
+                                      on_delete=models.DO_NOTHING,
+                                      db_constraint=False,
+                                      default='')
     order_no = models.CharField(verbose_name='平台订单号', db_index=True, max_length=255, blank=True)
-    opposite_account = models.CharField(verbose_name='对方科目', max_length=255, blank=True, null=True, db_index=True)
+
+    account = models.ForeignKey(verbose_name='账户', to=BaseInfo, db_column='account_id', related_name='account_set',
+                                on_delete=models.DO_NOTHING, db_constraint=False)
+    their_account = models.ForeignKey(verbose_name='对方账户', to=BaseInfo, db_column='their_account_id',
+                                      related_name='their_account_set',
+                                      on_delete=models.DO_NOTHING, db_constraint=False)
+
+    transact_time = models.DateTimeField(verbose_name='交易时间', auto_now_add=True)
+
     summary = models.CharField(verbose_name='摘要说明', max_length=255, blank=True, null=True)
+
     currency = models.ForeignKey(verbose_name='币种', to=Currency, db_column='currency_id', related_name='+',
                                  on_delete=models.DO_NOTHING, default=1, unique=False, blank=True, null=True,
+                                 db_constraint=False,
                                  help_text='')
+    pay_mode = models.ForeignKey(verbose_name='支付方式', to=PayMode, db_column='pay_mode_id', on_delete=models.DO_NOTHING,
+                                 db_constraint=False,
+                                 unique=False, blank=True, null=True, default=5)
+
+    opposite_account = models.CharField(verbose_name='对方科目', blank=True, null=True, max_length=255, )
+
     income = models.DecimalField(verbose_name='收入', max_digits=32, decimal_places=8, blank=True, null=True,
                                  db_index=True)
     outgo = models.DecimalField(verbose_name='支出', max_digits=32, decimal_places=8, blank=True, null=True,
                                 db_index=True)
     balance = models.DecimalField(verbose_name='余额', max_digits=32, decimal_places=8, db_index=True, default=0)
-    pay_mode = models.ForeignKey(verbose_name='支付方式', to=PayMode, db_column='pay_mode_id', on_delete=models.DO_NOTHING,
-                                 unique=False, blank=True, null=True, default=5)
-    thread_id = models.BigIntegerField(verbose_name='资金id', db_index=True, null=True, )
+
     goods_info = models.JSONField(verbose_name='商品信息', blank=True, null=True)
     pay_info = models.JSONField(verbose_name='付款信息', blank=True, null=True)
     remark = models.TextField(verbose_name='备注', blank=True, null=True)
     images = models.CharField(verbose_name='多图上传', blank=True, null=True, max_length=1000)
     sand_box = models.ForeignKey(verbose_name='沙盒', to=SandBox, db_column='sand_box_id', related_name='+',
-                                 on_delete=models.DO_NOTHING, unique=False, blank=True, null=True, db_index=True)
-    finance_status_code = models.IntegerField(verbose_name='资金状态码', default='')
+                                 on_delete=models.DO_NOTHING, unique=False, blank=True, null=True, db_index=True,
+                                 db_constraint=False, )
+    finance_status_code = models.CharField(verbose_name='资金状态码', default='', max_length=32, blank=True, null=True)
     is_reverse = models.BooleanField(verbose_name='是否红冲', blank=True, null=True)
     is_delete = models.BooleanField(verbose_name='是否删除', blank=True, null=True)
     is_write_off = models.BooleanField(verbose_name='是否核销', max_length=255, blank=True, null=True)
     sand_box_status_code = models.CharField(verbose_name='沙盒状态码', max_length=32, blank=True, null=True)
     snapshot = models.JSONField(verbose_name='快照', blank=True, null=True)
-    # money_flow = models.CharField(verbose_name='资金流行为', blank=True, null=True, max_length=1000)
+    bookkeeping_type = models.CharField(verbose_name='记账类型', blank=True, null=True, max_length=1000)
 
     class Meta:
         db_table = 'finance_transact'
