@@ -15,7 +15,7 @@ class FinanceSandBoxService:
     def get():
         currencies = SandBox.objects.all().annotate(value=F('sand_box_name'), sand_box=F('sand_box_name'))
 
-        return list(currencies.values('value', 'sand_box', 'sand_box_name', 'sand_box_label', 'description'))
+        return list(currencies.values('value', 'sand_box', 'sand_box_name', 'sand_box_label', 'description', 'config'))
 
     @staticmethod
     def post(params):
